@@ -5,8 +5,7 @@
 #
 # Reference:
 #
-# F.T. Cerasoli, A.R. Supka, A. Jayaraj, I. Siloi, M. Costa, J. Slawinska, S. Curtarolo, M. Fornari, D. Ceresoli, and M. Buongiorno Nardelli,
-# Advanced modeling of materials with PAOFLOW 2.0: New features and software design, Comp. Mat. Sci. 200, 110828 (2021).
+#F.T. Cerasoli, A.R. Supka, A. Jayaraj, I. Siloi, M. Costa, J. Slawinska, S. Curtarolo, M. Fornari, D. Ceresoli, and M. Buongiorno Nardelli, Advanced modeling of materials with PAOFLOW 2.0: New features and software design, Comp. Mat. Sci. 200, 110828 (2021).
 #
 # M. Buongiorno Nardelli, F. T. Cerasoli, M. Costa, S Curtarolo,R. De Gennaro, M. Fornari, L. Liyanage, A. Supka and H. Wang, 
 # PAOFLOW: A utility to construct and operate on ab initio Hamiltonians from the Projections of electronic wavefunctions on 
@@ -145,7 +144,8 @@ def do_build_pao_hamiltonian ( data_controller ):
 
     # Shift the Fermi energy to zero
     tshape = (ashape[0],ashape[1],nkpnts,ashape[5])
-    Ef = E_Fermi(arry['Hks'].reshape(tshape), data_controller)
+   # Ef = E_Fermi(arry['Hks'].reshape(tshape), data_controller)
+    Ef = 0
     dinds = np.diag_indices(attr['nawf'])
     arry['Hks'][dinds[0],dinds[1]] -= Ef
 
